# AnyDI Django

<div style="text-align: center;">

AnyDI Django extension.

[![CI](https://github.com/antonrh/anydi-django/actions/workflows/ci.yml/badge.svg)](https://github.com/antonrh/anydi/actions/workflows/ci.yml)
[![Coverage](https://codecov.io/gh/antonrh/anydi-django/branch/main/graph/badge.svg)](https://codecov.io/gh/antonrh/anydi)

</div>

---

## 📘 Overview

**AnyDI Django** is an official extension for integrating [AnyDI](https://github.com/antonrh/anydi) — a lightweight dependency injection framework — into Django projects.

---

## 📖 Documentation

Full documentation is available here:

🔗 [https://anydi.readthedocs.io/en/stable/extensions/django/](https://anydi.readthedocs.io/en/stable/extensions/django/)

---

## ⚙️ Installation

Install `AnyDI` for `Django`:

```bash
pip install anydi-django
```

Or install with Django Ninja integration:

```bash
pip install anydi-django[ninja]
```
